import { type AstNode, type LangiumDocuments } from 'langium';
import { type ExportDefinition, type ExportableElement, type JayveeModel } from './generated/ast';
import { type BlockTypeWrapper, type ConstraintTypeWrapper, type WrapperFactoryProvider } from './wrappers';
export type AstTypeGuard<T extends AstNode = AstNode> = (obj: unknown) => obj is T;
/**
 * Recursively goes upwards through the AST until it finds an AST node that satisfies the given type guard.
 * The entered AST node itself cannot be the result.
 * @param node The current AST node to start the search from.
 * @param guard The type guard function to check if a container matches the desired type.
 * @returns The desired container node that satisfies the type guard, or undefined if not found.
 */
export declare function getNextAstNodeContainer<T extends AstNode>(node: AstNode, guard: AstTypeGuard<T>): T | undefined;
/**
 * Utility function that gets all builtin block types.
 * Duplicates are only added once.
 * Make sure to call {@link initializeWorkspace} first so that the file system is initialized.
 */
export declare function getAllBuiltinBlockTypes(documentService: LangiumDocuments, wrapperFactories: WrapperFactoryProvider): BlockTypeWrapper[];
/**
 * Utility function that gets all builtin constraint types.
 * Duplicates are only added once.
 * Make sure to call {@link initializeWorkspace} first so that the file system is initialized.
 */
export declare function getAllBuiltinConstraintTypes(documentService: LangiumDocuments, wrapperFactories: WrapperFactoryProvider): ConstraintTypeWrapper[];
export interface ExportDetails {
    /**
     * The exported element
     */
    element: ExportableElement;
    /**
     * The name which the exported element is available under.
     */
    exportName: string;
}
/**
 * Gets all exported elements from a document.
 * This logic cannot reside in a {@link ScopeComputationProvider} but should be handled here:
 * https://github.com/eclipse-langium/langium/discussions/1508#discussioncomment-9524544
 */
export declare function getExportedElements(model: JayveeModel): ExportDetails[];
/**
 * Follow an export statement to its original definition.
 */
export declare function followExportDefinitionChain(exportDefinition: ExportDefinition): ExportableElement | undefined;
/**
 * Checks whether an exportable @param element is exported (either in definition or via an delayed export definition).
 */
export declare function isElementExported(element: ExportableElement): boolean;
