import { type BlockDefinition, type CompositeBlockTypeDefinition, type PipelineDefinition } from '../generated/ast';
import { type AstNodeWrapper } from './ast-node-wrapper';
import { type PipeWrapper } from './pipe-wrapper';
import { type IPipeWrapperFactory } from './wrapper-factory-provider';
export declare class PipelineWrapper<T extends PipelineDefinition | CompositeBlockTypeDefinition> implements AstNodeWrapper<T> {
    readonly astNode: T;
    allPipes: PipeWrapper[];
    constructor(pipesContainer: T, pipeWrapperFactory: IPipeWrapperFactory);
    static canBeWrapped(pipesContainer: PipelineDefinition | CompositeBlockTypeDefinition, pipeWrapperFactory: IPipeWrapperFactory): boolean;
    getStartingBlockPipes(): PipeWrapper[];
    getStartingBlocks(): BlockDefinition[];
    getOutgoingPipes(blockDefinition: BlockDefinition): PipeWrapper[];
    getChildBlocks(blockDefinition: BlockDefinition): BlockDefinition[];
    getIngoingPipes(blockDefinition: BlockDefinition): PipeWrapper[];
    getParentBlocks(blockDefinition: BlockDefinition): BlockDefinition[];
    /**
     * Returns blocks in a pipeline in topological order, based on
     * Kahn's algorithm.
     *
     * Considers a pipeline as a directed, acyclical graph where
     * blocks are nodes and pipes are edges. A list in topological
     * order has the property that parent nodes are always listed
     * before their children.
     *
     * "[...] a list in topological order is such that no element
     * appears in it until after all elements appearing on all paths
     * leading to the particular element have been listed."
     *
     * Kahn, A. B. (1962). Topological sorting of large networks. Communications of the ACM, 5(11), 558–562.
     */
    getBlocksInTopologicalSorting(): BlockDefinition[];
}
