import { type AstNode, type MaybePromise, type ValidationCheck, ValidationRegistry } from 'langium';
import { EvaluationContext, type ValueTypeProvider, type WrapperFactoryProvider } from '../ast';
import { type JayveeAstType } from '../ast/generated/ast';
import type { JayveeServices } from '../jayvee-module';
import { type JayveeImportResolver } from '../services/import-resolver';
import { ValidationContext } from './validation-context';
/**
 * Registry for validation checks.
 */
export declare class JayveeValidationRegistry extends ValidationRegistry {
    private readonly runtimeParameterProvider;
    private readonly typeComputerRegistry;
    private readonly operatorEvaluatorRegistry;
    private readonly wrapperFactories;
    private readonly valueTypeProvider;
    private readonly importResolver;
    constructor(services: JayveeServices);
    registerJayveeValidationChecks(checksRecord: JayveeValidationChecks): void;
    private wrapJayveeValidationCheck;
}
export type JayveeValidationChecks<T = JayveeAstType> = {
    [K in keyof T]?: T[K] extends AstNode ? JayveeValidationCheck<T[K]> : never;
} & {
    AstNode?: ValidationCheck<AstNode>;
};
export interface JayveeValidationProps {
    validationContext: ValidationContext;
    evaluationContext: EvaluationContext;
    wrapperFactories: WrapperFactoryProvider;
    valueTypeProvider: ValueTypeProvider;
    importResolver: JayveeImportResolver;
}
export type JayveeValidationCheck<T extends AstNode = AstNode> = (node: T, props: JayveeValidationProps) => MaybePromise<void>;
